/*
ZgeSpeak Library
Copyright (c) 2015 Radovan Cervenka

This software is provided 'as-is', without any express or implied
warranty. In no event will the authors be held liable for any damages
arising from the use of this software.

Permission is granted to anyone to use this software for any purpose,
including commercial applications, and to alter it and redistribute it
freely, subject to the following restrictions:

1. The origin of this software must not be misrepresented; you must not
   claim that you wrote the original software. If you use this software
   in a product, an acknowledgment in the product documentation would be
   appreciated but is not required.

2. Altered source versions must be plainly marked as such, and must not be
   misrepresented as being the original software.

3. This notice may not be removed or altered from any source distribution.
*/

package org.zgameeditor;

import android.speech.tts.TextToSpeech;

import java.util.HashMap;
import java.util.Locale;

//import android.util.Log;

public class ZgeSpeak {

    private static TextToSpeech tts;
    private static boolean isTtsReady = false;

    public static void init(){

        tts = new TextToSpeech(ZgeActivity.zgeActivity.getApplicationContext(),
                new TextToSpeech.OnInitListener() {
                    @Override
                    public void onInit(int status) {
                        if(status != TextToSpeech.ERROR){
                            //int res = tts.setLanguage(Locale.ENGLISH);
                            //isTtsReady = res != TextToSpeech.LANG_NOT_SUPPORTED &&
                            //             res != TextToSpeech.LANG_MISSING_DATA;
                            isTtsReady = true;
                        }
                    }
                }
            );
    }

    public static void finish() {
        if (tts != null){
            tts.stop();
            tts.shutdown();
        }

        isTtsReady = false;
    }

    public static boolean speak(String text){
        if (isTtsReady)
            return tts.speak(text, TextToSpeech.QUEUE_FLUSH, null) != TextToSpeech.ERROR;
        else
            return false;
    }

    public static void stopSpeaking(){
        if (isTtsReady) tts.stop();
    }

    public static boolean isSpeaking(){
        return isTtsReady && tts.isSpeaking();
    }

    public static boolean isSpeakingReady(){
        return isTtsReady;
    }

    public static boolean isIsTtsReady(){
        return isTtsReady;
    }

    public static boolean setLanguage(String language, String country){
        if (isTtsReady)
            return tts.setLanguage(new Locale(language, country)) == TextToSpeech.SUCCESS;
        else
            return false;
    }

    public static void setPitch(float pitch){
        if (isTtsReady) tts.setPitch(pitch);
    }

    public static void setSpeechRate(float speechRate){
        if (isTtsReady) tts.setSpeechRate(speechRate);
    }
}